/*

	Step 1 of 3, Object To Volume Process (ToVolume)
	RegisterObject.pov
	2013 Sam Benge
 
	This file produces three numbers that will be used to define the voxel resolution of your data.
	These numbers are useful for other things as well, as you will see later.
	
	Directions:
		* scroll down to "begin user-defined settings"
		* determine how many frames you want for step #2, and set "TargetFrames" to that number
		* define/include your object and #declare "Obj" as your object
		* render the scene, making sure to save its image
		
	The image produced by this file displays your object, accompanied by the following three values:
		* a red "x"; this will be the width of the volume's resolution
		* a green "y"; this will be the height of the volume's resolution
		* a blue "z"; this will be the depth of the volume's resolution, and also the number of frames for step #2 (this is the number you will provide)
	
	recommended command line options:
		+fn +f +a0.3 +am2 +r3 +w640 h480
	
	Tip:
		* try to rotate your object so that its shortest dimension falls along the z-axis. This will maximize the resolution of the volumetric data. (This is because step #3 is currently limited to 256 frames....)
		
	Next step: Slice.pov
	
*/


#version 3.7;

//#macro Lerp(A, B, C) A*(1-C) + B*C #end

global_settings{
	assumed_gamma 1.0
	#if(1)
		radiosity{
			count 16
			error_bound .1
			recursion_limit 1
			nearest_count 1
			normal on
			pretrace_end .04/3
		}
	#end
}

// this is why everything is grainy
#default{ finish{ambient 0} normal{bumps .35 scale .001} }

#declare SunPos = vrotate(y, <-23, 45, 0>);
#declare RGBSun = srgb 0.625*<2, 1.95, 1.8>;
#declare RGBSky = rgb <.2, .3, .75>;

#declare CamPos = .175*<0, 0, -35>;
camera{
	location vrotate(CamPos, <45, 22, 0>)
	look_at <.5, 1.0, 0.5>
	angle 42
	
	// focal blur (works well with aa)
	// aperture .1 focal_point 0 blur_samples 10 variance 0
}

// faraway light_source
#if(1)
	light_source{
		SunPos*1e7, RGBSun
		
		photons{area_light}
		#if(1)
			#declare ALRes	= 3;
			#declare ALSize	= 0.03*1e7;
			area_light x*ALSize, z*ALSize, ALRes, ALRes
			jitter
			adaptive 1
		#end
	}
#end

// blue sky...
#if(1)
	sky_sphere{
		pigment{
			spherical
			translate vnormalize(SunPos)
			poly_wave 2
			
			color_map{
				[0 RGBSky]
				[1 RGBSun]
			}
		}
	}
#end

// scene objects
#if(1)
	
	//*** begin user-defined settings ***//
	
	// 256 max; this will be the number of slices (frames) in Slice.pov
	#declare TargetFrames	= 256/8;
	
	// your object here
	// all transformations given here will be needed again in Slice.pov
	#include "bowl_POV_geom.inc"
	#declare Obj =
		object{
			bowl_mesh_
			rotate x*270 // <-- remember any transformations given here, for steps 2 & 3!
		}
	
	//*** end user-defined settings ***//
	
	
	// calculations/object manipulation
	#declare Obj2 = object{Obj translate -min_extent(Obj)}
	#declare Obj3 = object{Obj2 scale 0.5/max_extent(Obj).z}
	#declare MXE = max_extent(Obj3);
	#declare ScaleRatio = 1/MXE.z;
	#declare ScaleMultiply	= TargetFrames*ScaleRatio;
	
	// the object in question
	object{
		Obj3
		scale ScaleRatio
		pigment{rgb 1}
	}
	
	// visible bounding box
	box{
		0, MXE
		pigment{
			function{
				max(
					0,
					min(
						1,
						max(
							1-2*max(abs(x-0.5), abs(y-0.5)),
							1-2*max(abs(y-0.5), abs(z-0.5)),
							1-2*max(abs(z-0.5), abs(x-0.5))
						)
					)
				)
			}
			scale MXE
			poly_wave 1/4
			color_map{
				[.2 rgb <1, 1, .5>]
				[.5 rgb <.9, .95, 1> filter 1]
			}
		}
		finish{diffuse .5, .5 brilliance 0}
		scale ScaleRatio
	}
	
	// gridded plane
	#if(1)
		plane{
			y, -1e-4
			pigment{
				function{1 - max(abs(mod(abs(x), 1)-0.5)*2, abs(mod(abs(z), 1)-0.5)*2)}
				color_map{
					[.05 rgb .3]
					[.05 rgb .75]
				}
			}
		}
	#end
	
	// text objects
	#if(1)
		union{
			
			#declare TxtThk	= 0.06;
			text{
				ttf "lucon.ttf"
				concat("x = ", str(MXE.x*ScaleMultiply, 0, 0))
				TxtThk, 0
				translate -z*TxtThk + y*2
				pigment{rgb x}
			}
			text{
				ttf "lucon.ttf"
				concat("y = ", str(MXE.y*ScaleMultiply, 0, 0))
				TxtThk, 0
				translate -z*TxtThk + y*1
				pigment{rgb y}
			}
			text{
				ttf "lucon.ttf"
				concat("z = ", str(MXE.z*ScaleMultiply, 0, 0))
				TxtThk, 0
				translate -z*TxtThk
				pigment{rgb z}
			}
			rotate x*90
			scale .25
			translate <-1.25, 0, .15>
		}
		
		// white text area
		box{
			<-1.5, 0, 0>,
			<0, TxtThk/2/4, 1>
			pigment{rgb 1}
		}
		
	#end
	

#end